@@ -97,7 +97,7 @@ createGraphFromHommelEtAl <- function(alpha=0.025) {
 			n2 <- hnodes[3+j]
 			graph <- addEdge(n1, n2, graph, 1/3)
 			x <- ((i+j)*200-200)/2+sign(i-j)*20
-			y <- 300 + (abs(i-j)*50)			
+			y <- 300 + (abs(i-j)*45)+sign(i-j)*5		
 			edgeData(graph, n1, n2, "labelX") <- x
 			edgeData(graph, n1, n2, "labelY") <- y
 		}
