@@ -10,7 +10,10 @@ checkValidAlpha <- function(alpha) {
 # Converts a string like "5+3*e+5*e^2" to the tupel representation c(5,3,5) 
 parseEpsPolynom <- function(s) {
 	e <- polynom()
-	eval(parse(text=paste("p <- ", s)))
+	p <- try(eval(parse(text=s)))
+	if (class(p)=="try-error") {
+		stop("String does not represent a polynom in e.")
+	}
 	if(is.numeric(p)) {
 		return(p)
 	} else {
